1.0.0 API documentation: exterior_product.hpp File Reference

| 1.0.0 API documentation

Functions
exterior_product.hpp File Reference

GLM_GTX_exterior_product More...

Go to the source code of this file.

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL GLM_CONSTEXPR T | cross (vec< 2, T, Q > const &v, vec< 2, T, Q > const &u)
| Returns the cross product of x and y. More...

## Detailed Description

GLM_GTX_exterior_product

See also
  Core features (dependence)
  GLM_GTX_exterior_product (dependence)

Definition in file exterior_product.hpp.